@@ -6,8 +6,14 @@ from maquinas.regular.REParser import REParser
 
 parser=REParser()
 
-class RE:
+class RegularExpression():
+    """Class for Regular Expressions
+
+    :param er_string: regular expressiones.
+    """
     def __init__(self, er_string):
+        if len(er_string.strip())==0:
+            raise NoStringWithDefinition(er_string,"RE")
         self.original=er_string
         self.ast=parser.parse(er_string,rulne_name="start")
 
@@ -42,5 +48,7 @@ class RE:
         return fa
 
     def ndfa_e(self):
-        return self._ndfa_e(self.ast)
+        """ Generates a NDFA-e equivalent to the ER
 
+        :returns: NDFA-e equivalent to ER"""
+        return self._ndfa_e(self.ast)
