@@ -614,12 +614,12 @@ class FiniteAutomaton():
             if isinstance(q,set):
                 g=self.save_img(filename_,q_c=q,a_c=set([a]),q_prev=q_prev,
                         symbols=symbols,states=states,
-                        dpi=dpi,string=(processed,a,w_))
+                        dpi=dpi,string=(processed,a,w_),format="png")
                 q_prev=q
             else:
                 g=self.save_img(filename_,q_c=set([q]),a_c=set([a]),q_prev=q_prev,
                         symbols=symbols,states=states,
-                        dpi=dpi,string=(processed,a,w_))
+                        dpi=dpi,string=(processed,a,w_),format="png")
                 q_prev=set([q])
             im=Image.open(filename_+".png")
             images.append(im)
@@ -627,10 +627,10 @@ class FiniteAutomaton():
             filename_=os.path.join(dirpath,f'{i}')
             if isinstance(q,set):
                 g=self.save_img(filename_,q_c=q,
-                        symbols=symbols,dpi=dpi,string=(processed,a,w_))
+                        symbols=symbols,dpi=dpi,string=(processed,a,w_),format="png")
             else:
                 g=self.save_img(filename_,q_c=set([q]),
-                        symbols=symbols,dpi=dpi,string=(processed,a,w_))
+                        symbols=symbols,dpi=dpi,string=(processed,a,w_),format="png")
             im=Image.open(filename_+".png")
             if i==0 or len(w_)==0:
                 images.append(im)
